@@ -1,7 +1,6 @@
 #include "cardgame.h"
 
-
-extern byte colorInversionMask;
+#include "pmode4game_private.h"
 
 
 void enableInvertedColorText(BOOL enabled)
