@@ -13,6 +13,10 @@
 
 extern TextAreaScrollCallback textAreaScrollCallback;
 extern void *textAreaScrollCallbackUserData;
+extern byte colorInversionMask;
+extern BOOL drawRowOverGlyphWhenColorsInverted;
+extern BOOL drawColumnAtRightOfGlyphWhenColorsInverted;
+extern BOOL transparentSpaceChar;
 
 
 #endif  /* _H_pmode4game_private */
